beamprofiler.iso.characterizing\_parameters.clip\_level\_irradiation\_area
==========================================================================

.. currentmodule:: beamprofiler.iso.characterizing_parameters

.. autofunction:: clip_level_irradiation_area